Package: multiverse
Version: 0.6.2
Date: 2024-10-07
Title: Create 'multiverse analysis' in R
Authors@R: c(
        person("Abhraneel", "Sarma", role = c("aut", "cre"), email = "abhraneel@u.northwestern.edu"),
        person("Matthew", "Kay", role = "aut", email = "mjskay@northwestern.edu"),
        person("Michael", "Moon", role = "ctb", email = "moon@utstat.toronto.edu"),
        person("Mark", "Miller", role = "ctb", email = "725mrm@gmail.com"),
        person("Kyle", "Hwang", role = "ctb", email = "kyle.sg.hwang@gmail.com"),
        person("Hadley", "Wickham", role = "ctb", email = "hadley@posit.co"),
        person("Alex", "Kale", role = "ctb", email = "kalea@uw.edu"),
        person("Nathan", "Taback", role = "ctb", email = "nathan.taback@utoronto.ca"),
        person("Fanny", "Chevalier", role = "ctb", email = "fanny@dgp.toronto.edu"),
        person("Jessica", "Hullman", role = "ctb", email = "jessica.hullman@gmail.com"),
        person("Pierre", "Dragicevic", role = "ctb", email = "pierre.dragicevic@inria.fr"),
        person("Yvonne", "Jansen", role = "ctb", email = "yvonne.jansen@sorbonne-universite.fr")
    )
Maintainer: Abhraneel Sarma <abhraneel@u.northwestern.edu>
Description: Implement 'multiverse' style analyses (Steegen S., Tuerlinckx F, Gelman A., Vanpaemal, W., 2016)
    <doi:10.1177/1745691616658637> to show the robustness of statistical inference. 
    'Multiverse analysis' is a philosophy of statistical reporting where paper authors 
    report the outcomes of many different statistical analyses in order to show how 
    fragile or robust their findings are. The 'multiverse' package 
    (Sarma A., Kale A., Moon M., Taback N., Chevalier F., Hullman J., Kay M., 2021) 
    <doi:10.31219/osf.io/yfbwm> allows users to concisely and flexibly implement 'multiverse-style' 
    analysis, which involve declaring alternate ways of performing an analysis step, in R and R Notebooks.
License: GPL (>= 3)
Encoding: UTF-8
RoxygenNote: 7.3.2
Depends: R (>= 3.5.0), knitr (>= 1.3.2)
Imports: dplyr (>= 0.8.1), purrr (>= 0.3.4), rlang (>= 0.4.0), R6,
        methods, tidyr (>= 1.0.0), tibble, magrittr, tidyselect,
        formatR, collections, evaluate, rstudioapi, berryFunctions,
        furrr, styler, distributional, jsonlite, readr
Suggests: ggplot2 (>= 3.0.0), testthat (>= 3.0.0), highr, rmarkdown,
        covr, broom, boot, gganimate, gifski, forcats, stringr,
        cowplot, tidybayes, png, stringi, modelr, future
VignetteBuilder: knitr
Language: en-US
BugReports: https://github.com/MUCollective/multiverse/issues/
URL: https://mucollective.github.io/multiverse/,
        https://github.com/mucollective/multiverse/
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2024-10-07 18:33:52 UTC; abhraneel
Author: Abhraneel Sarma [aut, cre],
  Matthew Kay [aut],
  Michael Moon [ctb],
  Mark Miller [ctb],
  Kyle Hwang [ctb],
  Hadley Wickham [ctb],
  Alex Kale [ctb],
  Nathan Taback [ctb],
  Fanny Chevalier [ctb],
  Jessica Hullman [ctb],
  Pierre Dragicevic [ctb],
  Yvonne Jansen [ctb]
Repository: CRAN
Date/Publication: 2024-10-07 23:20:03 UTC
Built: R 4.6.0; ; 2026-04-26 19:58:46 UTC; unix
