# Generated by roxygen2: do not edit by hand

S3method("$",multiverse)
S3method("$<-",multiverse)
S3method(code,default)
S3method(code,multiverse)
S3method(conditions,default)
S3method(conditions,multiverse)
S3method(expand,default)
S3method(expand,multiverse)
S3method(extract_variables,data.frame)
S3method(extract_variables,multiverse)
S3method(parameters,default)
S3method(parameters,multiverse)
S3method(print,multiverse)
S3method(size,default)
S3method(size,multiverse)
export(code)
export(conditions)
export(execute_multiverse)
export(execute_universe)
export(expand)
export(export_code_json)
export(export_data_json)
export(export_results_dist_json)
export(export_results_json)
export(extract_variable_from_universe)
export(extract_variables)
export(inside)
export(is.multiverse)
export(is_multiverse)
export(multiverse)
export(parameters)
export(size)
export(style_multiverse_code)
importFrom(R6,R6Class)
importFrom(berryFunctions,tryStack)
importFrom(collections,ordered_dict)
importFrom(distributional,cdf)
importFrom(distributional,dist_normal)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,lag)
importFrom(dplyr,lead)
importFrom(dplyr,mutate)
importFrom(dplyr,rename)
importFrom(dplyr,select)
importFrom(dplyr,summarise_all)
importFrom(formatR,tidy_source)
importFrom(furrr,future_map)
importFrom(jsonlite,write_json)
importFrom(knitr,knit_engines)
importFrom(knitr,knit_global)
importFrom(magrittr,"%>%")
importFrom(magrittr,extract2)
importFrom(magrittr,inset)
importFrom(methods,is)
importFrom(purrr,compact)
importFrom(purrr,map)
importFrom(purrr,map2)
importFrom(purrr,map_chr)
importFrom(purrr,reduce)
importFrom(readr,guess_parser)
importFrom(rlang,as_name)
importFrom(rlang,caller_env)
importFrom(rlang,enexpr)
importFrom(rlang,enquo)
importFrom(rlang,enquos)
importFrom(rlang,env)
importFrom(rlang,expr)
importFrom(rlang,expr_text)
importFrom(rlang,f_lhs)
importFrom(rlang,f_rhs)
importFrom(rlang,is_call)
importFrom(rlang,is_condition)
importFrom(rlang,is_empty)
importFrom(rlang,is_missing)
importFrom(rlang,is_null)
importFrom(rlang,is_symbol)
importFrom(rlang,parse_expr)
importFrom(rlang,quo)
importFrom(rlang,quo_text)
importFrom(rstudioapi,getActiveDocumentContext)
importFrom(rstudioapi,insertText)
importFrom(rstudioapi,setCursorPosition)
importFrom(stats,quantile)
importFrom(styler,create_style_guide)
importFrom(styler,style_text)
importFrom(tibble,as_tibble)
importFrom(tibble,tibble)
importFrom(tidyr,nest)
importFrom(tidyr,pivot_longer)
importFrom(tidyr,pivot_wider)
importFrom(tidyr,unnest_longer)
importFrom(tidyr,unnest_wider)
importFrom(tidyselect,everything)
importFrom(tidyselect,starts_with)
importFrom(utils,assignInNamespace)
importFrom(utils,globalVariables)
importFrom(utils,head)
importFrom(utils,setTxtProgressBar)
importFrom(utils,tail)
importFrom(utils,txtProgressBar)
